@@ -1,17 +1,16 @@
-#!/usr/local/bin/perl -w
 require 5.000;
 
-use Parse::CLex;
-
-print STDERR "Version $Parse::ALex::VERSION\n";
+use Parse::Lex;
+print STDERR "Version $Parse::Lex::VERSION\n";
 @token = qw(
 	    ADDOP    [-+]
 	    INTEGER  [1-9][0-9]*
 	   );
 
-$lexer = Parse::CLex->new(@token);
+$lexer = Parse::Lex->new(@token);
 $lexer->from(\*DATA);
 
+Parse::Token->trace();
 $content = $INTEGER->next;
 if ($INTEGER->status) {
   print "$content\n";
