@@ -4,7 +4,7 @@ use strict qw(refs);
 use strict qw(subs);
 
 package Parse::Token;		# or perhaps: Parse::AToken
-$Parse::Token::VERSION = '2.15';
+$Parse::Token::VERSION = '2.16';
 use Parse::Trace;
 @Parse::Token::ISA = qw(Parse::Trace);
 
@@ -1127,7 +1127,7 @@ sub _buildRegexp {
 
 package Parse::Token::Nested;
 use Parse::Trace;
-@Parse::Token::Nested::ISA = qw(Parse::Token::Nested Parse::Trace);
+@Parse::Token::Nested::ISA = qw(Parse::Trace);
 
 # Examples:
 # (+ (* 3 4) 4)
